==> igniteui-react-charts-18.1.0.tgz: package/esm5/lib/AbsoluteVolumeOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { IShortPeriodLongPeriod_$type } from "./IShortPeriodLongPeriod";
import { AbsoluteVolumeOscillatorIndicatorStrategy } from "./AbsoluteVolumeOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
var AbsoluteVolumeOscillatorIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(AbsoluteVolumeOscillatorIndicator, _super);
    function AbsoluteVolumeOscillatorIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AbsoluteVolumeOscillatorIndicator.prototype.get_ul = function () {
        return new AbsoluteVolumeOscillatorIndicatorStrategy();
    };
    Object.defineProperty(AbsoluteVolumeOscillatorIndicator.prototype, "ul", {
        get: function () {
            return this.get_ul();
        },
        enumerable: false,
        configurable: true
    });
    AbsoluteVolumeOscillatorIndicator.prototype.get_uy = function () {
        return AbsoluteVolumeOscillatorIndicator.$;
    };
    Object.defineProperty(AbsoluteVolumeOscillatorIndicator.prototype, "uy", {
        get: function () {
            return this.get_uy();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(AbsoluteVolumeOscillatorIndicator.prototype, "shortPeriod", {
        get: function () {
            return typeGetValue(this.c(AbsoluteVolumeOscillatorIndicator.u7));
        },
        set: function (a) {
            this.h(AbsoluteVolumeOscillatorIndicator.u7, a);
        },
        enumerable: false,
        configurable: true
    });
    AbsoluteVolumeOscillatorIndicator.prototype.ut = function () {
        return this.shortPeriod;
    };
    Object.defineProperty(AbsoluteVolumeOscillatorIndicator.prototype, "longPeriod", {
        get: function () {
            return typeGetValue(this.c(AbsoluteVolumeOscillatorIndicator.u6));
        },
        set: function (a) {
            this.h(AbsoluteVolumeOscillatorIndicator.u6, a);
        },
        enumerable: false,
        configurable: true
    });
    AbsoluteVolumeOscillatorIndicator.prototype.uq = function () {
        return this.longPeriod;
    };
    AbsoluteVolumeOscillatorIndicator.$t = markType(AbsoluteVolumeOscillatorIndicator, 'AbsoluteVolumeOscillatorIndicator', StrategyBasedIndicator.$, [IShortPeriodLongPeriod_$type]);
    AbsoluteVolumeOscillatorIndicator.u7 = StrategyBasedIndicator.u5(10, AbsoluteVolumeOscillatorIndicator.$);
    AbsoluteVolumeOscillatorIndicator.u6 = StrategyBasedIndicator.u1(30, AbsoluteVolumeOscillatorIndicator.$);
    return AbsoluteVolumeOscillatorIndicator;
}(StrategyBasedIndicator));
export { AbsoluteVolumeOscillatorIndicator };

==> igniteui-react-charts-18.2.0.tgz: package/esm5/lib/AbsoluteVolumeOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { IShortPeriodLongPeriod_$type } from "./IShortPeriodLongPeriod";
import { AbsoluteVolumeOscillatorIndicatorStrategy } from "./AbsoluteVolumeOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
var AbsoluteVolumeOscillatorIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(AbsoluteVolumeOscillatorIndicator, _super);
    function AbsoluteVolumeOscillatorIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AbsoluteVolumeOscillatorIndicator.prototype.get_up = function () {
        return new AbsoluteVolumeOscillatorIndicatorStrategy();
    };
    Object.defineProperty(AbsoluteVolumeOscillatorIndicator.prototype, "up", {
        get: function () {
            return this.get_up();
        },
        enumerable: false,
        configurable: true
    });
    AbsoluteVolumeOscillatorIndicator.prototype.get_u2 = function () {
        return AbsoluteVolumeOscillatorIndicator.$;
    };
    Object.defineProperty(AbsoluteVolumeOscillatorIndicator.prototype, "u2", {
        get: function () {
            return this.get_u2();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(AbsoluteVolumeOscillatorIndicator.prototype, "shortPeriod", {
        get: function () {
            return typeGetValue(this.c(AbsoluteVolumeOscillatorIndicator.vb));
        },
        set: function (a) {
            this.h(AbsoluteVolumeOscillatorIndicator.vb, a);
        },
        enumerable: false,
        configurable: true
    });
    AbsoluteVolumeOscillatorIndicator.prototype.ux = function () {
        return this.shortPeriod;
    };
    Object.defineProperty(AbsoluteVolumeOscillatorIndicator.prototype, "longPeriod", {
        get: function () {
            return typeGetValue(this.c(AbsoluteVolumeOscillatorIndicator.va));
        },
        set: function (a) {
            this.h(AbsoluteVolumeOscillatorIndicator.va, a);
        },
        enumerable: false,
        configurable: true
    });
    AbsoluteVolumeOscillatorIndicator.prototype.uu = function () {
        return this.longPeriod;
    };
    AbsoluteVolumeOscillatorIndicator.$t = markType(AbsoluteVolumeOscillatorIndicator, 'AbsoluteVolumeOscillatorIndicator', StrategyBasedIndicator.$, [IShortPeriodLongPeriod_$type]);
    AbsoluteVolumeOscillatorIndicator.vb = StrategyBasedIndicator.u9(10, AbsoluteVolumeOscillatorIndicator.$);
    AbsoluteVolumeOscillatorIndicator.va = StrategyBasedIndicator.u5(30, AbsoluteVolumeOscillatorIndicator.$);
    return AbsoluteVolumeOscillatorIndicator;
}(StrategyBasedIndicator));
export { AbsoluteVolumeOscillatorIndicator };
